import os
from dotenv import load_dotenv
import datetime

load_dotenv()

class Config:
    SECRET_KEY = os.getenv('SECRET_KEY', 'mysecretkey')
    SQLALCHEMY_DATABASE_URI = os.getenv('DATABASE_URL', 'postgresql://user:password@localhost/dbname')
    SCHEMA_NAME = os.getenv('DATABASE_SCHEMA')
    SQLALCHEMY_TRACK_MODIFICATIONS = False
    DEBUG = os.getenv('FLASK_ENV') == 'development'
    PORT = int(os.getenv('PORT', 8000))
    JWT_SECRET_KEY = os.getenv('JWT_SECRET_KEY', 'myjwtsecretkey')
    JWT_ACCESS_TOKEN_EXPIRES = datetime.timedelta(minutes=1440)
    JWT_REFRESH_TOKEN_EXPIRES = datetime.timedelta(days=7)
    MAIL_SERVER = os.getenv('MAIL_SERVER', 'smtp.example.com')
    MAIL_PORT = os.getenv('MAIL_PORT', 587)
    MAIL_USE_TLS = os.getenv('MAIL_USE_TLS', True)
    MAIL_USERNAME = os.getenv('MAIL_USERNAME')
    MAIL_PASSWORD = os.getenv('MAIL_PASSWORD')
    MAIL_DEFAULT_SENDER = os.getenv('MAIL_DEFAULT_SENDER')
    APP_NAME = os.getenv('APP_NAME')

    SWAGGER_TITLE = os.getenv('SWAGGER_TITLE', 'API Documentation')
    SWAGGER_DESCRIPTION = os.getenv('SWAGGER_DESCRIPTION', 'API documentation')
    SWAGGER_VERSION = os.getenv('SWAGGER_VERSION', '1.0.0')

    LOG_FILE = os.getenv('LOG_FILE', 'logs/app.log')
    
    
