from app import db
from werkzeug.security import generate_password_hash, check_password_hash
from app.config import Config
from datetime import datetime
import pytz

jakarta_timezone = pytz.timezone('Asia/Jakarta')
current_time = datetime.now(jakarta_timezone)
    
class User(db.Model):
    __tablename__ = 'auth_user'
    __table_args__ = {'schema': Config.SCHEMA_NAME }
    
    id = db.Column(db.Integer, primary_key=True)
    created_date = db.Column(db.DateTime, nullable=False)
    updated_date = db.Column(db.DateTime, nullable=False)
    telegram_id = db.Column(db.Integer, nullable=False)
    role_id = db.Column(db.Integer, nullable=False)
    password = db.Column(db.String(500), nullable=False)
    file_path = db.Column(db.String(500), nullable=True)
    username = db.Column(db.String(150), unique=True, nullable=False)
    first_name = db.Column(db.String(150), unique=True, nullable=False)
    last_name = db.Column(db.String(150), unique=True, nullable=False)
    email = db.Column(db.String(150), unique=True, nullable=True, default='admin@admin.com')
    current_refresh_token = db.Column(db.String(500), nullable=True)

    # roles = db.relationship('Role', secondary='user_roles', backref=db.backref('users', lazy='dynamic'))


    def set_password(self, password):
        self.password = generate_password_hash(password)

    def check_password(self, password):
        return check_password_hash(self.password, password)

# Role model
# class Role(db.Model):
#     __tablename__ = 'role'
#     __table_args__ = {'schema': Config.SCHEMA_NAME }

#     id = db.Column(db.Integer, primary_key=True)
#     name = db.Column(db.String(50), unique=True)
    # privileges = db.relationship('Privilege', secondary='role_privileges', backref=db.backref('roles', lazy='dynamic'))

# Privilege model
# class Privilege(db.Model):

#     __tablename__ = 'privilege'
#     __table_args__ = {'schema': Config.SCHEMA_NAME }

#     id = db.Column(db.Integer, primary_key=True)
#     name = db.Column(db.String(50), unique=True)

# # Association tables
# user_roles = db.Table('user_roles',
#     db.Column('user_id', db.Integer, db.ForeignKey('user.id')),
#     db.Column('role_id', db.Integer, db.ForeignKey('role.id'))
# )

# role_privileges = db.Table('role_privileges',
#     db.Column('role_id', db.Integer, db.ForeignKey('role.id')),
#     db.Column('privilege_id', db.Integer, db.ForeignKey('privilege.id'))
# )